<?php
/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2022 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace CloudLinux\SmartAdvice\App\Service;

/**
 * Mailer
 */
abstract class Mailer {
	/**
	 * Headers.
	 *
	 * @return string[]
	 */
	public function headers() {
		return array( 'Content-Type: text/html; charset=UTF-8' );
	}

	/**
	 * Can send to WP users.
	 *
	 * @return bool
	 */
	abstract public function availableToWpUsers();

	/**
	 * Can send to Panel users.
	 *
	 * @return bool
	 */
	abstract public function availableToPanelUsers();

	/**
	 * Subject.
	 *
	 * @param string $site_url url.
	 *
	 * @return string
	 */
	abstract public function subject( $site_url );

	/**
	 * Template file.
	 *
	 * @return string
	 */
	abstract public function template();

	/**
	 * Template data.
	 *
	 * @return array
	 */
	abstract public function payload();

	/**
	 * Allows template data filtering for each email separately. Mail service populated the data with default attributes
	 * and merged with payload from mailer.
	 *
	 * @param  string $email  Email address.
	 * @param  array  $data  Template data.
	 *
	 * @return array
	 */
	public function filter_template_data( $email, $data ) {
		return $data;
	}

	/**
	 * Allows mailers to execute some actions after email was sent.
	 *
	 * @param  bool   $success  True if the email was sent successfully. False if there was an error.
	 * @param  string $user_type  Type of user.
	 * @param  string $email  Email.
	 * @param  string $subject  Letter subject.
	 * @param  string $body  Letter body.
	 * @param  array  $headers  Letter header.
	 *
	 * @return void
	 */
	public function post_email_sent( $success, $user_type, $email, $subject, $body, $headers ) {
		// Do nothing by default.
	}

	/**
	 * Allows initializing of analytics service.
	 *
	 * @param string $salt Salt.
	 *
	 * @return void
	 */
	public function init_analytics( $salt ) {
		// No analytics by default.
	}
}
