<?php
/**
 * Copyright (с) Cloud Linux GmbH & Cloud Linux Software, Inc 2010-2022 All Rights Reserved
 *
 * Licensed under CLOUD LINUX LICENSE AGREEMENT
 * https://www.cloudlinux.com/legal/
 */

namespace CloudLinux\SmartAdvice\App\Views;

use CloudLinux\SmartAdvice\App\View;
use CloudLinux\SmartAdvice\App\Service\Analytics;

/**
 * Admin
 */
class Admin extends View {

	/**
	 * Analytics service.
	 *
	 * @var Analytics
	 */
	private $analytics;

	/**
	 * Constructor.
	 *
	 * @param Analytics $analytics Analytics service.
	 */
	public function __construct( $analytics ) {
		$this->analytics = $analytics;

		add_action( 'admin_enqueue_scripts', array( $this, 'scripts' ) );
		add_action( 'admin_init', array( $this, 'init_analytics_session' ) );
	}

	/**
	 * Scripts and styles.
	 *
	 * @param string $hook_suffix The current admin page.
	 *
	 * @return void
	 */
	public function scripts( $hook_suffix ) {
		wp_register_style( 'cl-smart-advice-admin', false, array(), CL_SMART_ADVICE_VERSION );

		$paths = array( CL_SMART_ADVICE_FOLDER_PATH . '/assets/admin.css' );
		if ( $this->should_hide_object_cache_banners() ) {
			$paths[] = CL_SMART_ADVICE_FOLDER_PATH . '/assets/object-cache.css';
		}

		foreach ( $paths as $path ) {
			if ( is_readable( $path ) ) {
				// @phpcs:ignore WordPress.WP.AlternativeFunctions.file_get_contents_file_get_contents
				wp_add_inline_style( 'cl-smart-advice-admin', file_get_contents( $path ) );
				wp_enqueue_style( 'cl-smart-advice-admin' );
			}
		}

		$path = CL_SMART_ADVICE_FOLDER_PATH . '/assets/admin.js';
		if ( is_readable( $path ) ) {
			wp_register_script( 'cl-smart-advice-admin', false, array( 'jquery' ), CL_SMART_ADVICE_VERSION, true );
			wp_localize_script(
				'cl-smart-advice-admin',
				'clSmartAdviceConfig',
				array(
					'analyticsApiUrl' => $this->analytics->get_endpoint_url( Analytics::ENDPOINT_SEND ),
					'sessionData'     => $this->analytics->get_session_data(),
				)
			);
			wp_enqueue_script( 'cl-smart-advice-admin' );
			// @phpcs:ignore WordPress.WP.AlternativeFunctions.file_get_contents_file_get_contents
			wp_add_inline_script( 'cl-smart-advice-admin', file_get_contents( $path ) );
		}
	}

	/**
	 * Checks if object cache banners should be hidden.
	 *
	 * @return bool True if banners should be hidden, false otherwise.
	 */
	public function should_hide_object_cache_banners() {
		return defined( 'WP_REDIS_DISABLE_BANNERS' ) &&
			WP_REDIS_DISABLE_BANNERS &&
			is_plugin_active( 'redis-cache' ) &&
			defined( 'WP_PLUGIN_DIR' ) &&
			version_compare( '2.4.1', get_plugin_data( WP_PLUGIN_DIR . '/redis-cache/redis-cache.php' )['Version'], '>=' );
	}

	/**
	 * Initialized the analytics session using request data.
	 *
	 * @return void
	 */
	public function init_analytics_session() {
		$this->analytics->init_session( $_GET ); // @phpcs:ignore WordPress.Security.NonceVerification
	}
}

